==> jc-1.4.0.tar.gz: soot/javaToJimple/JavaToJimple__241.h <==
// class soot.javaToJimple.JavaToJimple$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo
// @dep_class 1e789ac64547e540 soot_javaToJimple_JavaToJimple__241
// @dep_class 155e6493c3c373f soot_javaToJimple_jj_ExtensionInfo

// header file dependencies
// @dep_header soot_javaToJimple_jj_ExtensionInfo

#include "soot/javaToJimple/jj/ExtensionInfo.h"

#ifndef _JC_soot_javaToJimple_JavaToJimple__241_H_
#define _JC_soot_javaToJimple_JavaToJimple__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_soot_javaToJimple_JavaToJimple$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$sub_refs	_jc_soot_javaToJimple_JavaToJimple__241$sub_refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs	_jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$refs	_jc_soot_javaToJimple_JavaToJimple__241$refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$nonrefs	_jc_soot_javaToJimple_JavaToJimple__241$nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$object	_jc_soot_javaToJimple_JavaToJimple__241$object;

typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vmethods	_jc_soot_javaToJimple_JavaToJimple__241$vmethods;
typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vtable	_jc_soot_javaToJimple_JavaToJimple__241$vtable;
typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vtype	_jc_soot_javaToJimple_JavaToJimple__241$vtype;

// Constructors
extern void _jc_soot_javaToJimple_JavaToJimple__241$method$_init$6481dca8095b2dc8(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_soot_javaToJimple_JavaToJimple$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple__241$method$passes$def8d891d63f548c(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_polyglot_frontend_Job$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_JavaToJimple__241$method_info$passes$def8d891d63f548c;

// Virtual methods structure
struct _jc_soot_javaToJimple_JavaToJimple__241$vmethods {
	struct _jc_object	*(*passes$def8d891d63f548c)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_polyglot_frontend_Job$object *);
};

// Vtable
struct _jc_soot_javaToJimple_JavaToJimple__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	soot_javaToJimple_jj_ExtensionInfo;
	_jc_soot_javaToJimple_JavaToJimple__241$vmethods	soot_javaToJimple_JavaToJimple__241;
};

// Vtype
struct _jc_soot_javaToJimple_JavaToJimple__241$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_JavaToJimple__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple__241$sub_refs {
	struct _jc_soot_javaToJimple_JavaToJimple$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple__241$refs {
    _jc_soot_javaToJimple_JavaToJimple__241$sub_refs	soot_javaToJimple_JavaToJimple__241;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs	soot_javaToJimple_JavaToJimple__241;
};

// Object instance structure
struct _jc_soot_javaToJimple_JavaToJimple__241$object {
	_jc_soot_javaToJimple_JavaToJimple__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_JavaToJimple__241$vtype	*vtype;
	_jc_soot_javaToJimple_JavaToJimple__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_JavaToJimple__241$vtype _jc_soot_javaToJimple_JavaToJimple__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_JavaToJimple__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_JavaToJimple__241$class_object;

#endif	/* _JC_soot_javaToJimple_JavaToJimple__241_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/JavaToJimple__241.h <==
// class soot.javaToJimple.JavaToJimple$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo
// @dep_class 1e789ac64547e540 soot_javaToJimple_JavaToJimple__241
// @dep_class 155e6493c3c373f soot_javaToJimple_jj_ExtensionInfo

// header file dependencies
// @dep_header soot_javaToJimple_jj_ExtensionInfo

#include "soot/javaToJimple/jj/ExtensionInfo.h"

#ifndef _JC_soot_javaToJimple_JavaToJimple__241_H_
#define _JC_soot_javaToJimple_JavaToJimple__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_soot_javaToJimple_JavaToJimple$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$sub_refs	_jc_soot_javaToJimple_JavaToJimple__241$sub_refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs	_jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$refs	_jc_soot_javaToJimple_JavaToJimple__241$refs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$nonrefs	_jc_soot_javaToJimple_JavaToJimple__241$nonrefs;
typedef struct _jc_soot_javaToJimple_JavaToJimple__241$object	_jc_soot_javaToJimple_JavaToJimple__241$object;

typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vmethods	_jc_soot_javaToJimple_JavaToJimple__241$vmethods;
typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vtable	_jc_soot_javaToJimple_JavaToJimple__241$vtable;
typedef const struct _jc_soot_javaToJimple_JavaToJimple__241$vtype	_jc_soot_javaToJimple_JavaToJimple__241$vtype;

// Constructors
extern void _jc_soot_javaToJimple_JavaToJimple__241$method$_init$6481dca8095b2dc8(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_soot_javaToJimple_JavaToJimple$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_JavaToJimple__241$method$passes$def8d891d63f548c(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_JavaToJimple__241$method_info$passes$def8d891d63f548c;

// Virtual methods structure
struct _jc_soot_javaToJimple_JavaToJimple__241$vmethods {
	struct _jc_object	*(*passes$def8d891d63f548c)(_jc_env *, struct _jc_soot_javaToJimple_JavaToJimple__241$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_JavaToJimple__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_soot_javaToJimple_jj_ExtensionInfo$vmethods	soot_javaToJimple_jj_ExtensionInfo;
	_jc_soot_javaToJimple_JavaToJimple__241$vmethods	soot_javaToJimple_JavaToJimple__241;
};

// Vtype
struct _jc_soot_javaToJimple_JavaToJimple__241$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_JavaToJimple__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple__241$sub_refs {
	struct _jc_soot_javaToJimple_JavaToJimple$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple__241$refs {
    _jc_soot_javaToJimple_JavaToJimple__241$sub_refs	soot_javaToJimple_JavaToJimple__241;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_refs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_JavaToJimple__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_soot_javaToJimple_jj_ExtensionInfo$sub_nonrefs	soot_javaToJimple_jj_ExtensionInfo;
    _jc_soot_javaToJimple_JavaToJimple__241$sub_nonrefs	soot_javaToJimple_JavaToJimple__241;
};

// Object instance structure
struct _jc_soot_javaToJimple_JavaToJimple__241$object {
	_jc_soot_javaToJimple_JavaToJimple__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_JavaToJimple__241$vtype	*vtype;
	_jc_soot_javaToJimple_JavaToJimple__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_JavaToJimple__241$vtype _jc_soot_javaToJimple_JavaToJimple__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_JavaToJimple__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_JavaToJimple__241$class_object;

#endif	/* _JC_soot_javaToJimple_JavaToJimple__241_H_ */
